"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLevelName = exports.getLevelNumber = exports.rfcLogLevels = void 0;
/** Default levels are according to the [RFC Standard](http://www.faqs.org/rfcs/rfc3164.html) */
exports.rfcLogLevels = {
    emergency: 0,
    alert: 1,
    critical: 2,
    error: 3,
    warning: 4,
    notice: 5,
    info: 6,
    debug: 7,
    emerg: 0,
    crit: 2,
    err: 3,
    warn: 4,
    note: 5,
};
/**
 * Determine the level number from a level name
 */
function getLevelNumber(name, levels) {
    if (levels === void 0) { levels = exports.rfcLogLevels; }
    if (levels[name] == null) {
        return null;
    }
    else {
        return levels[name];
    }
}
exports.getLevelNumber = getLevelNumber;
/**
 * Determine the level name from a level number
 */
function getLevelName(number, levels) {
    if (levels === void 0) { levels = exports.rfcLogLevels; }
    for (var name_1 in levels) {
        if (levels.hasOwnProperty(name_1)) {
            var value = levels[name_1];
            if (value === number) {
                return name_1;
            }
        }
    }
    return null;
}
exports.getLevelName = getLevelName;
/**
 * Receive either the level name or number and return the combination.
 * @param level Either a log name or a log number that is contained within the levels mapping
 * @param levels A mapping of permitted log names to their log numbers to determine the correct log level name and number combination
 * @returns The found combination, which if provided an alias, expands it. If an invalid level was provided, `null` is returned.
 * @example input
 * ``` javascript
 * import getLevelInfo, { rfcLogLevels } from 'rfc-log-levels'
 * getLevelInfo('note')
 * getLevelInfo('note', rfcLogLevels)
 * getLevelInfo('note', { note: 5 })
 * ```
 * @example result
 * ``` json
 * {
 * 	"levelNumber": 5,
 * 	"levelName": "notice"
 * }
 * ```
 */
function getLevelInfo(level, levels) {
    if (levels === void 0) { levels = exports.rfcLogLevels; }
    if (typeof level === 'string') {
        // get number from input name
        var levelNumber = getLevelNumber(level, levels);
        if (levelNumber == null)
            return null;
        // input name could have been shortened, so get the expanded name
        var levelName = getLevelName(levelNumber, levels);
        if (levelName == null)
            return null;
        // return
        return { levelNumber: levelNumber, levelName: levelName };
    }
    else if (typeof level === 'number') {
        // get the expanded name from the input number
        var levelName = getLevelName(level, levels);
        if (levelName == null)
            return null;
        // return
        return { levelNumber: level, levelName: levelName };
    }
    else {
        return null;
    }
}
exports.default = getLevelInfo;
